# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/search.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/search.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2
from iotics.api import feed_pb2 as iotics_dot_api_dot_feed__pb2
from iotics.api import input_pb2 as iotics_dot_api_dot_input__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17iotics/api/search.proto\x12\niotics.api\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto\x1a\x17iotics/api/common.proto\x1a\x15iotics/api/feed.proto\x1a\x16iotics/api/input.proto\"\xf3\x04\n\rSearchRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\'\n\x05scope\x18\x02 \x01(\x0e\x32\x11.iotics.api.ScopeR\x05scope\x12\x30\n\x04lang\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04lang\x12;\n\x07payload\x18\x06 \x01(\x0b\x32!.iotics.api.SearchRequest.PayloadR\x07payload\x12\'\n\x05range\x18\x14 \x01(\x0b\x32\x11.iotics.api.RangeR\x05range\x1a\xf1\x02\n\x07Payload\x12<\n\x0cresponseType\x18\x01 \x01(\x0e\x32\x18.iotics.api.ResponseTypeR\x0cresponseType\x12@\n\rexpiryTimeout\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rexpiryTimeout\x12@\n\x06\x66ilter\x18\x03 \x01(\x0b\x32(.iotics.api.SearchRequest.Payload.FilterR\x06\x66ilter\x1a\xa3\x01\n\x06\x46ilter\x12\x30\n\x04text\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x04text\x12\x31\n\x08location\x18\x02 \x01(\x0b\x32\x15.iotics.api.GeoCircleR\x08location\x12\x34\n\nproperties\x18\x03 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\"\xbe\x02\n\x15\x41\x64vancedSearchRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\'\n\x05scope\x18\x02 \x01(\x0e\x32\x11.iotics.api.ScopeR\x05scope\x12\x43\n\x07payload\x18\x03 \x01(\x0b\x32).iotics.api.AdvancedSearchRequest.PayloadR\x07payload\x12\'\n\x05range\x18\x14 \x01(\x0b\x32\x11.iotics.api.RangeR\x05range\x1a_\n\x07Payload\x12<\n\x0cresponseType\x18\x01 \x01(\x0e\x32\x18.iotics.api.ResponseTypeR\x0cresponseType\x12\x16\n\x06\x66ilter\x18\x02 \x01(\tR\x06\x66ilter\"\xae\x07\n\x0eSearchResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12<\n\x07payload\x18\x02 \x01(\x0b\x32\".iotics.api.SearchResponse.PayloadR\x07payload\x1a\x8d\x01\n\x0b\x46\x65\x65\x64\x44\x65tails\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\x12\x1c\n\tstoreLast\x18\x03 \x01(\x08R\tstoreLast\x12\x34\n\nproperties\x18\x04 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x1as\n\x0cInputDetails\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\x12\x34\n\nproperties\x18\x04 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x1a\xdd\x02\n\x0bTwinDetails\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x12\x33\n\x08location\x18\x02 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\x12\x34\n\nproperties\x18\x05 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12<\n\x05\x66\x65\x65\x64s\x18\n \x03(\x0b\x32&.iotics.api.SearchResponse.FeedDetailsR\x05\x66\x65\x65\x64s\x12?\n\x06inputs\x18\x0b \x03(\x0b\x32\'.iotics.api.SearchResponse.InputDetailsR\x06inputs\x12\x38\n\tupdatedAt\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1a\xc9\x01\n\x07Payload\x12<\n\x0cresponseType\x18\x01 \x01(\x0e\x32\x18.iotics.api.ResponseTypeR\x0cresponseType\x12*\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusR\x06status\x12\x16\n\x06hostId\x18\x03 \x01(\tR\x06hostId\x12<\n\x05twins\x18\n \x03(\x0b\x32&.iotics.api.SearchResponse.TwinDetailsR\x05twins\"\x18\n\x16\x44ispatchSearchResponse*2\n\x0cResponseType\x12\x08\n\x04\x46ULL\x10\x00\x12\x0b\n\x07LOCATED\x10\x01\x12\x0b\n\x07MINIMAL\x10\x02\x32\xe8\x02\n\tSearchAPI\x12X\n\x15\x44ispatchSearchRequest\x12\x19.iotics.api.SearchRequest\x1a\".iotics.api.DispatchSearchResponse\"\x00\x12N\n\x11SynchronousSearch\x12\x19.iotics.api.SearchRequest\x1a\x1a.iotics.api.SearchResponse\"\x00\x30\x01\x12\\\n\x19ReceiveAllSearchResponses\x12\x1f.iotics.api.SubscriptionHeaders\x1a\x1a.iotics.api.SearchResponse\"\x00\x30\x01\x12S\n\x0e\x41\x64vancedSearch\x12!.iotics.api.AdvancedSearchRequest\x1a\x1a.iotics.api.SearchResponse\"\x00\x30\x01\x42\x7f\n\x0e\x63om.iotics.apiB\x0bSearchProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.search_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\013SearchProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_RESPONSETYPE']._serialized_start=2123
  _globals['_RESPONSETYPE']._serialized_end=2173
  _globals['_SEARCHREQUEST']._serialized_start=202
  _globals['_SEARCHREQUEST']._serialized_end=829
  _globals['_SEARCHREQUEST_PAYLOAD']._serialized_start=460
  _globals['_SEARCHREQUEST_PAYLOAD']._serialized_end=829
  _globals['_SEARCHREQUEST_PAYLOAD_FILTER']._serialized_start=666
  _globals['_SEARCHREQUEST_PAYLOAD_FILTER']._serialized_end=829
  _globals['_ADVANCEDSEARCHREQUEST']._serialized_start=832
  _globals['_ADVANCEDSEARCHREQUEST']._serialized_end=1150
  _globals['_ADVANCEDSEARCHREQUEST_PAYLOAD']._serialized_start=1055
  _globals['_ADVANCEDSEARCHREQUEST_PAYLOAD']._serialized_end=1150
  _globals['_SEARCHRESPONSE']._serialized_start=1153
  _globals['_SEARCHRESPONSE']._serialized_end=2095
  _globals['_SEARCHRESPONSE_FEEDDETAILS']._serialized_start=1281
  _globals['_SEARCHRESPONSE_FEEDDETAILS']._serialized_end=1422
  _globals['_SEARCHRESPONSE_INPUTDETAILS']._serialized_start=1424
  _globals['_SEARCHRESPONSE_INPUTDETAILS']._serialized_end=1539
  _globals['_SEARCHRESPONSE_TWINDETAILS']._serialized_start=1542
  _globals['_SEARCHRESPONSE_TWINDETAILS']._serialized_end=1891
  _globals['_SEARCHRESPONSE_PAYLOAD']._serialized_start=1894
  _globals['_SEARCHRESPONSE_PAYLOAD']._serialized_end=2095
  _globals['_DISPATCHSEARCHRESPONSE']._serialized_start=2097
  _globals['_DISPATCHSEARCHRESPONSE']._serialized_end=2121
  _globals['_SEARCHAPI']._serialized_start=2176
  _globals['_SEARCHAPI']._serialized_end=2536
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/input.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/input.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16iotics/api/input.proto\x12\niotics.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17iotics/api/common.proto\"I\n\x07InputID\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x16\n\x06twinId\x18\x02 \x01(\tR\x06twinId\x12\x16\n\x06hostId\x18\x03 \x01(\tR\x06hostId\"\xbd\x01\n\x12\x44\x65leteInputRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12<\n\x04\x61rgs\x18\x02 \x01(\x0b\x32(.iotics.api.DeleteInputRequest.ArgumentsR\x04\x61rgs\x1a:\n\tArguments\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xc1\x01\n\x13\x44\x65leteInputResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.DeleteInputResponse.PayloadR\x07payload\x1a\x38\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\x97\x02\n\x12\x43reateInputRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12<\n\x04\x61rgs\x18\x02 \x01(\x0b\x32(.iotics.api.CreateInputRequest.ArgumentsR\x04\x61rgs\x12@\n\x07payload\x18\x03 \x01(\x0b\x32&.iotics.api.CreateInputRequest.PayloadR\x07payload\x1a\x19\n\x07Payload\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xc1\x01\n\x13\x43reateInputResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.CreateInputResponse.PayloadR\x07payload\x1a\x38\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xf2\x02\n\x12UpdateInputRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12<\n\x04\x61rgs\x18\x02 \x01(\x0b\x32(.iotics.api.UpdateInputRequest.ArgumentsR\x04\x61rgs\x12@\n\x07payload\x18\x03 \x01(\x0b\x32&.iotics.api.UpdateInputRequest.PayloadR\x07payload\x1aq\n\x07Payload\x12*\n\x06values\x18\x01 \x01(\x0b\x32\x12.iotics.api.ValuesR\x06values\x12:\n\nproperties\x18\x02 \x01(\x0b\x32\x1a.iotics.api.PropertyUpdateR\nproperties\x1a:\n\tArguments\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xc1\x01\n\x13UpdateInputResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x41\n\x07payload\x18\x02 \x01(\x0b\x32\'.iotics.api.UpdateInputResponse.PayloadR\x07payload\x1a\x38\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xc1\x01\n\x14\x44\x65scribeInputRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12>\n\x04\x61rgs\x18\x02 \x01(\x0b\x32*.iotics.api.DescribeInputRequest.ArgumentsR\x04\x61rgs\x1a:\n\tArguments\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\xfa\x02\n\x15\x44\x65scribeInputResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x43\n\x07payload\x18\x02 \x01(\x0b\x32).iotics.api.DescribeInputResponse.PayloadR\x07payload\x1am\n\nMetaResult\x12)\n\x06values\x18\x01 \x03(\x0b\x32\x11.iotics.api.ValueR\x06values\x12\x34\n\nproperties\x18\x02 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x1a~\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\x12\x44\n\x06result\x18\x02 \x01(\x0b\x32,.iotics.api.DescribeInputResponse.MetaResultR\x06result\"\x86\x01\n\x13UpsertInputWithMeta\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12)\n\x06values\x18\x02 \x03(\x0b\x32\x11.iotics.api.ValueR\x06values\x12\x34\n\nproperties\x18\x03 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\"r\n\x0cInputMessage\x12:\n\noccurredAt\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\noccurredAt\x12\x12\n\x04mime\x18\x02 \x01(\tR\x04mime\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"\xcd\x01\n\x1aReceiveInputMessageRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x44\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\x30.iotics.api.ReceiveInputMessageRequest.ArgumentsR\x04\x61rgs\x1a:\n\tArguments\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\x85\x02\n\x1bReceiveInputMessageResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12I\n\x07payload\x18\x02 \x01(\x0b\x32/.iotics.api.ReceiveInputMessageResponse.PayloadR\x07payload\x1al\n\x07Payload\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\x12\x32\n\x07message\x18\x02 \x01(\x0b\x32\x18.iotics.api.InputMessageR\x07message2\xc5\x03\n\x08InputAPI\x12P\n\x0b\x44\x65leteInput\x12\x1e.iotics.api.DeleteInputRequest\x1a\x1f.iotics.api.DeleteInputResponse\"\x00\x12V\n\rDescribeInput\x12 .iotics.api.DescribeInputRequest\x1a!.iotics.api.DescribeInputResponse\"\x00\x12k\n\x14ReceiveInputMessages\x12&.iotics.api.ReceiveInputMessageRequest\x1a\'.iotics.api.ReceiveInputMessageResponse\"\x00\x30\x01\x12P\n\x0b\x43reateInput\x12\x1e.iotics.api.CreateInputRequest\x1a\x1f.iotics.api.CreateInputResponse\"\x00\x12P\n\x0bUpdateInput\x12\x1e.iotics.api.UpdateInputRequest\x1a\x1f.iotics.api.UpdateInputResponse\"\x00\x42~\n\x0e\x63om.iotics.apiB\nInputProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.input_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\nInputProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_INPUTID']._serialized_start=96
  _globals['_INPUTID']._serialized_end=169
  _globals['_DELETEINPUTREQUEST']._serialized_start=172
  _globals['_DELETEINPUTREQUEST']._serialized_end=361
  _globals['_DELETEINPUTREQUEST_ARGUMENTS']._serialized_start=303
  _globals['_DELETEINPUTREQUEST_ARGUMENTS']._serialized_end=361
  _globals['_DELETEINPUTRESPONSE']._serialized_start=364
  _globals['_DELETEINPUTRESPONSE']._serialized_end=557
  _globals['_DELETEINPUTRESPONSE_PAYLOAD']._serialized_start=501
  _globals['_DELETEINPUTRESPONSE_PAYLOAD']._serialized_end=557
  _globals['_CREATEINPUTREQUEST']._serialized_start=560
  _globals['_CREATEINPUTREQUEST']._serialized_end=839
  _globals['_CREATEINPUTREQUEST_PAYLOAD']._serialized_start=757
  _globals['_CREATEINPUTREQUEST_PAYLOAD']._serialized_end=782
  _globals['_CREATEINPUTREQUEST_ARGUMENTS']._serialized_start=784
  _globals['_CREATEINPUTREQUEST_ARGUMENTS']._serialized_end=839
  _globals['_CREATEINPUTRESPONSE']._serialized_start=842
  _globals['_CREATEINPUTRESPONSE']._serialized_end=1035
  _globals['_CREATEINPUTRESPONSE_PAYLOAD']._serialized_start=501
  _globals['_CREATEINPUTRESPONSE_PAYLOAD']._serialized_end=557
  _globals['_UPDATEINPUTREQUEST']._serialized_start=1038
  _globals['_UPDATEINPUTREQUEST']._serialized_end=1408
  _globals['_UPDATEINPUTREQUEST_PAYLOAD']._serialized_start=1235
  _globals['_UPDATEINPUTREQUEST_PAYLOAD']._serialized_end=1348
  _globals['_UPDATEINPUTREQUEST_ARGUMENTS']._serialized_start=303
  _globals['_UPDATEINPUTREQUEST_ARGUMENTS']._serialized_end=361
  _globals['_UPDATEINPUTRESPONSE']._serialized_start=1411
  _globals['_UPDATEINPUTRESPONSE']._serialized_end=1604
  _globals['_UPDATEINPUTRESPONSE_PAYLOAD']._serialized_start=501
  _globals['_UPDATEINPUTRESPONSE_PAYLOAD']._serialized_end=557
  _globals['_DESCRIBEINPUTREQUEST']._serialized_start=1607
  _globals['_DESCRIBEINPUTREQUEST']._serialized_end=1800
  _globals['_DESCRIBEINPUTREQUEST_ARGUMENTS']._serialized_start=303
  _globals['_DESCRIBEINPUTREQUEST_ARGUMENTS']._serialized_end=361
  _globals['_DESCRIBEINPUTRESPONSE']._serialized_start=1803
  _globals['_DESCRIBEINPUTRESPONSE']._serialized_end=2181
  _globals['_DESCRIBEINPUTRESPONSE_METARESULT']._serialized_start=1944
  _globals['_DESCRIBEINPUTRESPONSE_METARESULT']._serialized_end=2053
  _globals['_DESCRIBEINPUTRESPONSE_PAYLOAD']._serialized_start=2055
  _globals['_DESCRIBEINPUTRESPONSE_PAYLOAD']._serialized_end=2181
  _globals['_UPSERTINPUTWITHMETA']._serialized_start=2184
  _globals['_UPSERTINPUTWITHMETA']._serialized_end=2318
  _globals['_INPUTMESSAGE']._serialized_start=2320
  _globals['_INPUTMESSAGE']._serialized_end=2434
  _globals['_RECEIVEINPUTMESSAGEREQUEST']._serialized_start=2437
  _globals['_RECEIVEINPUTMESSAGEREQUEST']._serialized_end=2642
  _globals['_RECEIVEINPUTMESSAGEREQUEST_ARGUMENTS']._serialized_start=303
  _globals['_RECEIVEINPUTMESSAGEREQUEST_ARGUMENTS']._serialized_end=361
  _globals['_RECEIVEINPUTMESSAGERESPONSE']._serialized_start=2645
  _globals['_RECEIVEINPUTMESSAGERESPONSE']._serialized_end=2906
  _globals['_RECEIVEINPUTMESSAGERESPONSE_PAYLOAD']._serialized_start=2798
  _globals['_RECEIVEINPUTMESSAGERESPONSE_PAYLOAD']._serialized_end=2906
  _globals['_INPUTAPI']._serialized_start=2909
  _globals['_INPUTAPI']._serialized_end=3362
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: iotics/api/twin.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'iotics/api/twin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from iotics.api import common_pb2 as iotics_dot_api_dot_common__pb2
from iotics.api import feed_pb2 as iotics_dot_api_dot_feed__pb2
from iotics.api import input_pb2 as iotics_dot_api_dot_input__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15iotics/api/twin.proto\x12\niotics.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17iotics/api/common.proto\x1a\x15iotics/api/feed.proto\x1a\x16iotics/api/input.proto\"m\n\x13ListAllTwinsRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\'\n\x05range\x18\x14 \x01(\x0b\x32\x11.iotics.api.RangeR\x05range\"\xb9\x03\n\x14ListAllTwinsResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x42\n\x07payload\x18\x02 \x01(\x0b\x32(.iotics.api.ListAllTwinsResponse.PayloadR\x07payload\x1a\xde\x01\n\x0bTwinDetails\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x12\x33\n\x08location\x18\x03 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\x12\x34\n\nproperties\x18\x05 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12\x38\n\tupdatedAt\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1aM\n\x07Payload\x12\x42\n\x05twins\x18\x01 \x03(\x0b\x32,.iotics.api.ListAllTwinsResponse.TwinDetailsR\x05twins\"\x9e\x01\n\x11\x43reateTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12?\n\x07payload\x18\x02 \x01(\x0b\x32%.iotics.api.CreateTwinRequest.PayloadR\x07payload\x1a\x19\n\x07Payload\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xbc\x01\n\x12\x43reateTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.CreateTwinResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xb8\x01\n\x11\x44\x65leteTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12;\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\'.iotics.api.DeleteTwinRequest.ArgumentsR\x04\x61rgs\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xbc\x01\n\x12\x44\x65leteTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.DeleteTwinResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\xbc\x01\n\x13\x44\x65scribeTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12=\n\x04\x61rgs\x18\x03 \x01(\x0b\x32).iotics.api.DescribeTwinRequest.ArgumentsR\x04\x61rgs\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"T\n\x08\x46\x65\x65\x64Meta\x12*\n\x06\x66\x65\x65\x64Id\x18\x01 \x01(\x0b\x32\x12.iotics.api.FeedIDR\x06\x66\x65\x65\x64Id\x12\x1c\n\tstoreLast\x18\x03 \x01(\x08R\tstoreLast\":\n\tInputMeta\x12-\n\x07inputId\x18\x01 \x01(\x0b\x32\x13.iotics.api.InputIDR\x07inputId\"\x94\x04\n\x14\x44\x65scribeTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12\x42\n\x07payload\x18\x02 \x01(\x0b\x32(.iotics.api.DescribeTwinResponse.PayloadR\x07payload\x1a\x8c\x02\n\nMetaResult\x12\x33\n\x08location\x18\x01 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\x12*\n\x05\x66\x65\x65\x64s\x18\x04 \x03(\x0b\x32\x14.iotics.api.FeedMetaR\x05\x66\x65\x65\x64s\x12-\n\x06inputs\x18\x05 \x03(\x0b\x32\x15.iotics.api.InputMetaR\x06inputs\x12\x34\n\nproperties\x18\x06 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12\x38\n\tupdatedAt\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x1az\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x12\x43\n\x06result\x18\x02 \x01(\x0b\x32+.iotics.api.DescribeTwinResponse.MetaResultR\x06result\"H\n\x11GeoLocationUpdate\x12\x33\n\x08location\x18\x01 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\"\xfc\x02\n\x11UpdateTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12;\n\x04\x61rgs\x18\x02 \x01(\x0b\x32\'.iotics.api.UpdateTwinRequest.ArgumentsR\x04\x61rgs\x12?\n\x07payload\x18\x03 \x01(\x0b\x32%.iotics.api.UpdateTwinRequest.PayloadR\x07payload\x1a\x37\n\tArguments\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x1a\x80\x01\n\x07Payload\x12:\n\nproperties\x18\x03 \x01(\x0b\x32\x1a.iotics.api.PropertyUpdateR\nproperties\x12\x39\n\x08location\x18\x06 \x01(\x0b\x32\x1d.iotics.api.GeoLocationUpdateR\x08location\"\xbc\x01\n\x12UpdateTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.UpdateTwinResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\"\x95\x03\n\x11UpsertTwinRequest\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12?\n\x07payload\x18\x02 \x01(\x0b\x32%.iotics.api.UpsertTwinRequest.PayloadR\x07payload\x1a\x8f\x02\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId\x12\x34\n\nproperties\x18\x05 \x03(\x0b\x32\x14.iotics.api.PropertyR\nproperties\x12\x33\n\x08location\x18\x06 \x01(\x0b\x32\x17.iotics.api.GeoLocationR\x08location\x12\x34\n\x05\x66\x65\x65\x64s\x18\x07 \x03(\x0b\x32\x1e.iotics.api.UpsertFeedWithMetaR\x05\x66\x65\x65\x64s\x12\x37\n\x06inputs\x18\x08 \x03(\x0b\x32\x1f.iotics.api.UpsertInputWithMetaR\x06inputs\"\xbc\x01\n\x12UpsertTwinResponse\x12-\n\x07headers\x18\x01 \x01(\x0b\x32\x13.iotics.api.HeadersR\x07headers\x12@\n\x07payload\x18\x02 \x01(\x0b\x32&.iotics.api.UpsertTwinResponse.PayloadR\x07payload\x1a\x35\n\x07Payload\x12*\n\x06twinId\x18\x01 \x01(\x0b\x32\x12.iotics.api.TwinIDR\x06twinId2\xef\x03\n\x07TwinAPI\x12M\n\nCreateTwin\x12\x1d.iotics.api.CreateTwinRequest\x1a\x1e.iotics.api.CreateTwinResponse\"\x00\x12M\n\nUpsertTwin\x12\x1d.iotics.api.UpsertTwinRequest\x1a\x1e.iotics.api.UpsertTwinResponse\"\x00\x12M\n\nDeleteTwin\x12\x1d.iotics.api.DeleteTwinRequest\x1a\x1e.iotics.api.DeleteTwinResponse\"\x00\x12M\n\nUpdateTwin\x12\x1d.iotics.api.UpdateTwinRequest\x1a\x1e.iotics.api.UpdateTwinResponse\"\x00\x12S\n\x0c\x44\x65scribeTwin\x12\x1f.iotics.api.DescribeTwinRequest\x1a .iotics.api.DescribeTwinResponse\"\x00\x12S\n\x0cListAllTwins\x12\x1f.iotics.api.ListAllTwinsRequest\x1a .iotics.api.ListAllTwinsResponse\"\x00\x42}\n\x0e\x63om.iotics.apiB\tTwinProtoP\x01Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\xa2\x02\x03IAX\xaa\x02\nIotics.Api\xca\x02\nIotics\\Apib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'iotics.api.twin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\016com.iotics.apiB\tTwinProtoP\001Z>github.com/Iotic-Labs/iotic-go-proto-qapi/iotics/api;ioticsapi\242\002\003IAX\252\002\nIotics.Api\312\002\nIotics\\Api'
  _globals['_LISTALLTWINSREQUEST']._serialized_start=142
  _globals['_LISTALLTWINSREQUEST']._serialized_end=251
  _globals['_LISTALLTWINSRESPONSE']._serialized_start=254
  _globals['_LISTALLTWINSRESPONSE']._serialized_end=695
  _globals['_LISTALLTWINSRESPONSE_TWINDETAILS']._serialized_start=394
  _globals['_LISTALLTWINSRESPONSE_TWINDETAILS']._serialized_end=616
  _globals['_LISTALLTWINSRESPONSE_PAYLOAD']._serialized_start=618
  _globals['_LISTALLTWINSRESPONSE_PAYLOAD']._serialized_end=695
  _globals['_CREATETWINREQUEST']._serialized_start=698
  _globals['_CREATETWINREQUEST']._serialized_end=856
  _globals['_CREATETWINREQUEST_PAYLOAD']._serialized_start=831
  _globals['_CREATETWINREQUEST_PAYLOAD']._serialized_end=856
  _globals['_CREATETWINRESPONSE']._serialized_start=859
  _globals['_CREATETWINRESPONSE']._serialized_end=1047
  _globals['_CREATETWINRESPONSE_PAYLOAD']._serialized_start=994
  _globals['_CREATETWINRESPONSE_PAYLOAD']._serialized_end=1047
  _globals['_DELETETWINREQUEST']._serialized_start=1050
  _globals['_DELETETWINREQUEST']._serialized_end=1234
  _globals['_DELETETWINREQUEST_ARGUMENTS']._serialized_start=1179
  _globals['_DELETETWINREQUEST_ARGUMENTS']._serialized_end=1234
  _globals['_DELETETWINRESPONSE']._serialized_start=1237
  _globals['_DELETETWINRESPONSE']._serialized_end=1425
  _globals['_DELETETWINRESPONSE_PAYLOAD']._serialized_start=994
  _globals['_DELETETWINRESPONSE_PAYLOAD']._serialized_end=1047
  _globals['_DESCRIBETWINREQUEST']._serialized_start=1428
  _globals['_DESCRIBETWINREQUEST']._serialized_end=1616
  _globals['_DESCRIBETWINREQUEST_ARGUMENTS']._serialized_start=1179
  _globals['_DESCRIBETWINREQUEST_ARGUMENTS']._serialized_end=1234
  _globals['_FEEDMETA']._serialized_start=1618
  _globals['_FEEDMETA']._serialized_end=1702
  _globals['_INPUTMETA']._serialized_start=1704
  _globals['_INPUTMETA']._serialized_end=1762
  _globals['_DESCRIBETWINRESPONSE']._serialized_start=1765
  _globals['_DESCRIBETWINRESPONSE']._serialized_end=2297
  _globals['_DESCRIBETWINRESPONSE_METARESULT']._serialized_start=1905
  _globals['_DESCRIBETWINRESPONSE_METARESULT']._serialized_end=2173
  _globals['_DESCRIBETWINRESPONSE_PAYLOAD']._serialized_start=2175
  _globals['_DESCRIBETWINRESPONSE_PAYLOAD']._serialized_end=2297
  _globals['_GEOLOCATIONUPDATE']._serialized_start=2299
  _globals['_GEOLOCATIONUPDATE']._serialized_end=2371
  _globals['_UPDATETWINREQUEST']._serialized_start=2374
  _globals['_UPDATETWINREQUEST']._serialized_end=2754
  _globals['_UPDATETWINREQUEST_ARGUMENTS']._serialized_start=1179
  _globals['_UPDATETWINREQUEST_ARGUMENTS']._serialized_end=1234
  _globals['_UPDATETWINREQUEST_PAYLOAD']._serialized_start=2626
  _globals['_UPDATETWINREQUEST_PAYLOAD']._serialized_end=2754
  _globals['_UPDATETWINRESPONSE']._serialized_start=2757
  _globals['_UPDATETWINRESPONSE']._serialized_end=2945
  _globals['_UPDATETWINRESPONSE_PAYLOAD']._serialized_start=994
  _globals['_UPDATETWINRESPONSE_PAYLOAD']._serialized_end=1047
  _globals['_UPSERTTWINREQUEST']._serialized_start=2948
  _globals['_UPSERTTWINREQUEST']._serialized_end=3353
  _globals['_UPSERTTWINREQUEST_PAYLOAD']._serialized_start=3082
  _globals['_UPSERTTWINREQUEST_PAYLOAD']._serialized_end=3353
  _globals['_UPSERTTWINRESPONSE']._serialized_start=3356
  _globals['_UPSERTTWINRESPONSE']._serialized_end=3544
  _globals['_UPSERTTWINRESPONSE_PAYLOAD']._serialized_start=994
  _globals['_UPSERTTWINRESPONSE_PAYLOAD']._serialized_end=1047
  _globals['_TWINAPI']._serialized_start=3547
  _globals['_TWINAPI']._serialized_end=4042
# @@protoc_insertion_point(module_scope)
